"use strict";
class InnoError extends Error {
    constructor(code, internalLogObject = {}, httpStatus = 500) {
        super();
        this.errorPrefix = 'ERROR_';
        this.name = 'InnoError';
        this.code = this.errorPrefix + code;
        this.status = httpStatus;
        this.logObject = internalLogObject;
        this.stack = null;
        this.message = (new Date()).toISOString() +
            ' \nERROR_CODE: ' + this.code +
            ' \nERROR_HTTP_STATUS: ' + this.status +
            ' \nERROR_LOG_OBJECT: ' + JSON.stringify(this.logObject, InnoError.processError, 2);
    }
    static processError(key, value) {
        if (value instanceof Error) {
            const error = {};
            Object.getOwnPropertyNames(value).forEach(function (key) {
                error[key] = value[key];
            });
            return error;
        }
        return value;
    }
}
InnoError.INTERNAL = 'INTERNAL';
InnoError.DB_ERROR = 'DB_ERROR';
InnoError.AUTH = 'AUTH_TOKEN_IS_INVALID';
InnoError.NO_STRING = 'NO_STRING';
InnoError.NO_INT = 'NO_INT';
InnoError.NO_EMAIL = 'NO_EMAIL';
InnoError.INT_OUT_OF_BOUNDS = 'NO_INT';
InnoError.STRING_OUT_OF_BOUNDS = 'NO_INT';
exports.InnoError = InnoError;
